@@ -28,15 +28,14 @@
       !  derived attribues in the program).
 
 #define MAX_VERTEX  40
-       !     max number of vertexes of a component treatable.
+       !     max nubmer of vertexes of a component treatable.
        !     If a volume has a  curved surface (convex), vertex
        !     information is not used; NVTX=0 
-#define MAX_TOTCHA 2048
-       !    max number of total characters in a line.
-       !    A line includes concatinated lines by backslash
-#define MAX_SUBD  2000  
+
+#define MAX_SUBD  2000
+
        !     max number of sub-detectors definable
-#define MAX_COMPONENT_IN_SUBD  200000
+#define MAX_COMPONENT_IN_SUBD  80000
        !     max number of components in a sub detector
 #define MAX_SUBD_REF  2000
        !     max number of sub detectors that can be referred
@@ -51,7 +50,7 @@
 #define EPS_FOR_90  1.d-5
 
        !     scaler prod. of orthogonal unit vector must be <  this.
-#define MAX_NEW_STRUC  20
+#define MAX_NEW_STRUC  15
 
        !     max number of new structures definable by the user
 
@@ -61,7 +60,7 @@
 
 #define MAX_EQUATE  800
        !    max number of #equate definable
-#define MAX_CN_AREA  500000
+#define MAX_CN_AREA  400000
        !  max total number of comp. that appear as contained by
        !    other comp.s
 #define EPMAX_COMMENT  200
@@ -75,11 +74,5 @@
       !  max # of energy nodes at which exact cross-sections 
       !  are given for pair creation by muon at low eneries
       !  (3 GeV to 1500 GeV)
-#define MAXHEAVYCHG  30
-      !  max heavy charge treatable by SRIM data when dE/dx is calculated
-#define MAX_SRIMMEDIA  3
-      !  max # of  medias for which SRIM data can be applied. 
-#define MAX_STRUCCHR  16
-      !  from 12 to 16  v9.164
-#define MAX_MEDIANAMELENG 8
+#define MAX_STRUCCHR  12
 #endif
