@@ -1,11 +1,11 @@
-!      next one is   tentative sub for debug ; will  be detelet
+c      next one is   tentative sub for debug ; will  be detelet
       subroutine Lcompchk(id, no)
       implicit none
       character(*) id
       integer no
       if( no <= 0 ) then
          write(0, *)  " Lcomp (x) with x=", no, ' in ', id
-!         stop
+c         stop
       endif
       end
 
@@ -47,12 +47,12 @@
 
        ok = .true.
 
-       do i = 1, Det%nct
+       do i = 1, Det.nct
 !                get d,m,B
-          call epLightUnpackCountDE(Det%cmp(i)%CountDE, d, mn, B)
+          call epLightUnpackCountDE(Det.cmp(i).CountDE, d, mn, B)
 
           if( mn < LightNoMin )  then
-             Det%cmp(i)%LightCompNo = 0 ! this comp. is not related to light
+             Det.cmp(i).LightCompNo = 0 ! this comp. is not related to light
           else
              if( LightCompNo >= maxLightComp )  then
                 ! too many light components
@@ -61,13 +61,13 @@
      2             maxLightComp
                 write(0, *) 
      &            ' may be you must increase maxLightComp in ',
-     &            ' ZlightMaxDef%h'
+     &            ' ZlightMaxDef.h'
                 stop 0000
              endif
              LightCompNo = LightCompNo + 1
 
              Lcomp(LightCompNo)%mn = mn
-             Det%cmp(i)%LightCompNo = LightCompNo
+             Det.cmp(i).LightCompNo = LightCompNo
              Lcomp(LightCompNo)%compno = i
 
              exist = .false.    ! for mn check
@@ -79,26 +79,26 @@
              enddo
              if(exist) then
 !                 mn already in mnContainer
-!cc                if(Light /= 21) then
+ccc                if(Light /= 21) then
                    ! need ray tracing
                    Lcomp(LightCompNo)%comInfoNo = j  ! com info is here
                                                    ! i.e, comInfo(j)
 !                   Lcomp(LightCompNo)%mn = mn
-!cc                else
-!cc                   write(0,*)
-!cc     &               ' strange Light=21==>property file not needed'
-!cc                   write(0,*) 
-!cc     &              ' so we should not come here; in  epLightCountDE'
-!cc                   ok=.false.
-!cc                endif
+ccc                else
+ccc                   write(0,*)
+ccc     &               ' strange Light=21==>property file not needed'
+ccc                   write(0,*) 
+ccc     &              ' so we should not come here; in  epLightCountDE'
+ccc                   ok=.false.
+ccc                endif
              else
           !          new mn
-!cc                if(Light /= 21 ) then
+ccc                if(Light /= 21 ) then
                    if(mnCounter >= maxProperties) then
                       write(0,*)
      &                 ' too many diff. mn in CountDE>',
      &                   maxProperties
-                      write(0,*) ' see maxProperties in epLightMaDef%h'
+                      write(0,*) ' see maxProperties in epLightMaDef.h'
                       stop 5432
                    endif
                    mnCounter = mnCounter + 1
@@ -113,25 +113,25 @@
                    if( comInfo(mnCounter)%refracIndex(1) == 0.) then
                !     this is spcial. if refracindex is not given, use
                !     madia value; 
-                      mdno = Det%Cn2media(i)
-                      comInfo(mnCounter)%refracIndex = Media(mdno)%n
+                      mdno = Det.Cn2media(i)
+                      comInfo(mnCounter)%refracIndex = Media(mdno).n
                    endif
             !      read wave length distribution file etc, if spcified
 
                    call epLightReadAFFile(LightDir, Lcomp(LightCompNo),
      &                   comInfo(mnCounter) )
-!cc                endif
+ccc                endif
              endif
                !  compute some values and store Lcomp
                !  we should re-fix the two index values here 
                !  for known mn case
 
-             LightCompNo =  Det%cmp(i)%LightCompNo 
+             LightCompNo =  Det.cmp(i).LightCompNo 
 
-!             mnCounter =  Lcomp(LightCompNo)%comInfoNo 
+c             mnCounter =  Lcomp(LightCompNo)%comInfoNo 
              mnCounter_tmp =  Lcomp(LightCompNo)%comInfoNo   ! from Akaike
              call epLightManipInp(i,
-!     &           comInfo(mnCounter), Lcomp(LightCompNo) )
+c     &           comInfo(mnCounter), Lcomp(LightCompNo) )
      &           comInfo(mnCounter_tmp), Lcomp(LightCompNo) )  ! //
           endif
        enddo
@@ -152,7 +152,7 @@
        endif
        end  
 
-!           component # to Lcomp #
+c           component # to Lcomp #
       subroutine epLightCn2LcompNo(cmpNo, LcmpNo)
       implicit none
 
@@ -161,7 +161,7 @@
       integer cmpNo  ! input comp. #
       integer Lcmpno ! output. cn-->LightCompNO 
                     !  If not Light component, 0
-      LcmpNo = Det%cmp(cmpNo)%LightCompNo
+      LcmpNo = Det.cmp(cmpNo).LightCompNo
       end
       subroutine epLightLcompNo2Cn(LcmpNo, cmpNo)
       implicit none
@@ -173,11 +173,11 @@
       integer,allocatable,save::Lc2c(:)
       integer ic, ilc
       if( first ) then
-         allocate( Lc2c(Det%nct) )
+         allocate( Lc2c(Det.nct) )
          first = .false.
          Lc2c(:) = 0 
-         do ic = 1, Det%nct
-            ilc = Det%cmp(ic)%LightCompNo
+         do ic = 1, Det.nct
+            ilc = Det.cmp(ic).LightCompNo
             if(ilc > 0 ) then
                Lc2c(ilc) = ic
             endif
@@ -193,8 +193,8 @@
       
 !        set  countDE within program after reading config data.
 !        may be called by the user from uiav.
-!        If this is called, epLightCountDE( user ) must be
-!        called ; as to user see epLightCounDE  
+c        If this is called, epLightCountDE( user ) must be
+c        called ; as to user see epLightCounDE  
       subroutine epLightResetCountDE(cmpNo, cde)
       implicit none
 
@@ -202,8 +202,8 @@
 #include "Zcnfig.h"
       integer,intent(in):: cmpNo  !  comp. #
       integer,intent(in):: cde    ! . countDE to be set
-      if(cmpNo >= 1 .and. cmpNo <= Det%nct) then
-         Det%cmp(cmpNo)%CountDE = cde
+      if(cmpNo >= 1 .and. cmpNo <= Det.nct) then
+         Det.cmp(cmpNo).CountDE = cde
       else
          write(0,*) 'Warning from epLightResetCountDE:'
          write(0,*) ' specified comp.# ', cmpNo, ' non exsistent'
